@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.jobid.api-c/src/cjobid.c,v 1.8 2012/08/27 11:50:01 mvocu Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -244,12 +244,13 @@ char* glite_jobid_unparse(glite_jobid_const_t jobid)
     if (!jobid)
 	return NULL;
 
-    asprintf(&out, GLITE_JOBID_PROTO_PREFIX"%s:%d/%s%s%s",
+    if (asprintf(&out, GLITE_JOBID_PROTO_PREFIX"%s:%d/%s%s%s",
 	     jobid->BShost,
 	     jobid->BSport? jobid->BSport : GLITE_JOBID_DEFAULT_PORT,
 	     jobid->id,
 	     (jobid->info ? "?" : ""),
-	     (jobid->info ? jobid->info : ""));
+	     (jobid->info ? jobid->info : "")) == -1)
+	return NULL;
 
     return out;
 }
@@ -259,9 +260,12 @@ char* glite_jobid_getServer(glite_jobid_const_t jobid)
 {
     char *bs = NULL;
 
-    if (jobid)
-	asprintf(&bs, "%s:%u", jobid->BShost,
-		 jobid->BSport ? jobid->BSport : GLITE_JOBID_DEFAULT_PORT);
+    if (!jobid)
+	return NULL;
+
+    if (asprintf(&bs, "%s:%u", jobid->BShost,
+	     jobid->BSport ? jobid->BSport : GLITE_JOBID_DEFAULT_PORT) == -1)
+	return NULL;
 
     return bs;
 }
